@@ -14,7 +14,7 @@
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+//Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 //
 using System;
@@ -38,10 +38,13 @@ namespace LongoMatch.Gui
 		public event SegmentClosedHandler SegmentClosedEvent;
 		public event TickHandler Tick;
 		public event ErrorHandler Error;
+		public event StateChangeHandler StateChanged;
 		public event NextButtonClickedHandler Next;
 		public event PrevButtonClickedHandler Prev;
-		
-		private const int THUMBNAIL_WIDTH = 50;
+		public event DrawFrameHandler DrawFrame;
+		public event SeekEventHandler SeekEvent;
+			
+		private const int THUMBNAIL_MAX_WIDTH = 100;
 		private TickHandler tickHandler;
 		private IPlayer player;
 		private long length=0;
@@ -106,19 +109,37 @@ namespace LongoMatch.Gui
 			}
 		}
 		
-		public Pixbuf CurrentFrame{
+		public Pixbuf CurrentMiniatureFrame{
 			get{
-				Pixbuf pixbuf = player.GetCurrentFrame(50,50);				
-				if (pixbuf != null)
-					return pixbuf;
-				else return null;
+				Pixbuf pixbuf = player.GetCurrentFrame(THUMBNAIL_MAX_WIDTH,THUMBNAIL_MAX_WIDTH);				
+				return pixbuf;
 			}
 		}
 		
-		public bool LogoMode {
-			get{return player.LogoMode;}
+		public Pixbuf CurrentFrame{
+			get{return player.GetCurrentFrame();}
+		}
+		
+		public Pixbuf LogoPixbuf{
+			set{player.LogoPixbuf = value;}
+		}
+		
+		public bool DrawingMode {
+			set{player.DrawingMode= value;}
+		}
+		
+		public Pixbuf DrawingPixbuf {
+			set{player.DrawingPixbuf=value;}
+		}
+		
+		public bool LogoMode{
 			set{player.LogoMode = value;}
-		}		
+		}
+		
+		public bool ExpandLogo {
+			get{return player.ExpandLogo;}
+			set{player.ExpandLogo = value;}
+		}
 		
 		public Widget VideoWidget{
 			get{return ((Gtk.EventBox)player);}
@@ -193,31 +214,47 @@ namespace LongoMatch.Gui
 		
 		public void SeekTo(long time, bool accurate){
 			player.SeekTime(time,1,accurate);
+			if (SeekEvent != null)
+				SeekEvent(time);
 		}
 		
 		public void SeekInSegment(long pos){
 			player.SeekInSegment(pos, GetRateFromScale());
+			if (SeekEvent != null)
+				SeekEvent(pos);
 		}
 		
 		public void SeekToNextFrame(bool in_segment){
-			if (segmentStopTime==0 | player.CurrentTime < segmentStopTime)
+			int currentTime = (int)player.CurrentTime;
+			if (segmentStopTime==0 | currentTime < segmentStopTime){
 				player.SeekToNextFrame( GetRateFromScale(), in_segment);
+				if (SeekEvent != null)
+					SeekEvent(currentTime );
+			}
+			
 		}
 		
 		public void SeekToPreviousFrame(bool in_segment){
-			if (player.CurrentTime > segmentStartTime){
+			long currentTime = player.CurrentTime;
+			if (currentTime> segmentStartTime){
 				player.SeekToPreviousFrame( GetRateFromScale(),in_segment);
+				if (SeekEvent != null)
+					SeekEvent(currentTime);
 			}
 		}
 		
 		public void UpdateSegmentStartTime (long start){
 			segmentStartTime = start;
-			player.SegmentStartUpdate(start, GetRateFromScale());						
+			player.SegmentStartUpdate(start, GetRateFromScale());
+			if (SeekEvent != null)
+				SeekEvent(start);
 		}
 		
 		public void UpdateSegmentStopTime (long stop){
 			segmentStopTime = stop;
 			player.SegmentStopUpdate(stop, GetRateFromScale());	
+			if (SeekEvent != null)
+				SeekEvent(stop);
 		}
 		
 		public void SetStartStop(long start, long stop){
@@ -305,6 +342,8 @@ namespace LongoMatch.Gui
 				playbutton.Show();
 				pausebutton.Hide();
 			}
+			if (StateChanged != null)
+				StateChanged(this,args);
 		}
 		
 		protected void OnReadyToSeek(object o, EventArgs args){
@@ -487,6 +526,14 @@ namespace LongoMatch.Gui
 			else 
 				Pause();		
 		}
-#endregion		
+		
+		protected virtual void OnDrawButtonClicked (object sender, System.EventArgs e)
+		{
+			int currentTime;
+			Pixbuf frame=null;
+			if (DrawFrame != null)
+				DrawFrame((int)AccurateCurrentTime);
+		}
+#endregion	
 	}
 }
